@@ -12,7 +12,7 @@ from . tasks import *
 __all__ = ('CommandLineClient', 'LoggingMixin', 'MqttClient',
     'Skill', 'SnipsClient', 'SnipsError', 'SnipsClarificationError',
     'StateAwareMixin', 'conditional', 'when',
-    'cron', 'Scheduler',
+    'cron', 'now', 'Scheduler',
     'debug_json', 'get_translations', 'topic', 'min_confidence', 'MultiRoomConfig',
     'on_intent', 'intent', 'PARDON', 'require_slot',
     'on_hotword_detected', 'on_start_session', 'on_session_started',
@@ -20,4 +20,4 @@ __all__ = ('CommandLineClient', 'LoggingMixin', 'MqttClient',
     'CONFIRMATIONS', 'ROOMS', 'room_with_article', 'room_with_preposition')
 
 
-__version__ = '0.1.22'
+__version__ = '0.1.23'
