@@ -9,8 +9,11 @@ class LoggingMixin:
     'Logging for Snips events'
     
     INDENT = 10
+    tty_log = None
 
     def colored_log(self, level, format, *args, color=None):
+        if self.tty_log is None:
+            self.tty_log = logging.getLogger().handlers[0].stream.isatty()
         if color and self.tty_log: args = map(color, args)
         self.log.log(level, format, *args)
     
